@@ -1,5 +1,5 @@
 /**
- * Copyright (C) 2013-2019  Stefan Löffler
+ * Copyright (C) 2013-2020  Stefan Löffler
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the Free
@@ -14,14 +14,14 @@
 #ifndef PDFAnnotations_H
 #define PDFAnnotations_H
 
-#include <PDFActions.h>
+#include "PDFActions.h"
 
-#include <QString>
-#include <QRectF>
-#include <QPolygonF>
+#include <QColor>
 #include <QDateTime>
 #include <QFlags>
-#include <QColor>
+#include <QPolygonF>
+#include <QRectF>
+#include <QString>
 #include <QWeakPointer>
 
 namespace QtPDF {
@@ -65,13 +65,13 @@ public:
     AnnotationTypePrinterMark, AnnotationTypeTrapNet, AnnotationTypeWatermark,
     AnnotationType3D
   };
-  
-  AbstractAnnotation() { }
-  virtual ~AbstractAnnotation() { }
+
+  AbstractAnnotation() = default;
+  virtual ~AbstractAnnotation() = default;
 
   virtual AnnotationType type() const = 0;
   virtual bool isMarkup() const { return false; }
-  
+
   // Declare all the getter/setter methods virtual so derived classes can
   // override them
   virtual QRectF rect() const { return _rect; }
@@ -90,6 +90,8 @@ public:
   virtual void setLastModified(const QDateTime lastModified) { _lastModified = lastModified; }
   virtual void setColor(const QColor color) { _color = color; }
 
+  virtual bool operator==(const AbstractAnnotation & o) const;
+
 protected:
   QRectF _rect; // required, in pdf coordinates
   QString _contents; // optional
@@ -113,10 +115,12 @@ Q_DECLARE_OPERATORS_FOR_FLAGS(AbstractAnnotation::AnnotationFlags)
 class Markup : public AbstractAnnotation
 {
 public:
-  Markup() : AbstractAnnotation(), _popup(NULL) { }
-  virtual ~Markup();
+  Markup() : AbstractAnnotation() { }
+  ~Markup() override;
+  Markup(const Markup & o);
+  Markup & operator=(const Markup & o);
 
-  virtual bool isMarkup() const { return true; }
+  bool isMarkup() const override { return true; }
 
   virtual QString title() const { return _title; }
   // Synonym for title(), but easier to read
@@ -135,9 +139,11 @@ public:
   // Note: the Markup takes ownership of `popup`
   virtual void setPopup(Popup * popup);
 
+  bool operator==(const AbstractAnnotation & o) const override;
+
 protected:
   QString _title; // optional; since PDF 1.1; by convention identifies the annotation author
-  Popup * _popup;
+  Popup * _popup{nullptr};
   // float _opacity;
   QString _richContents; // optional; since PDF 1.5; may contain some HTML tags
   QDateTime _creationDate; // optional; since PDF 1.5
@@ -153,8 +159,8 @@ class Link : public AbstractAnnotation
 public:
   enum HighlightingMode { HighlightingNone, HighlightingInvert, HighlightingOutline, HighlightingPush };
 
-  Link() : AbstractAnnotation(), _highlightingMode(HighlightingNone), _actionOnActivation(NULL) { }
-  virtual ~Link();
+  Link() : AbstractAnnotation() { }
+  ~Link() override;
   Link(const Link & other) : AbstractAnnotation(other), _highlightingMode(other._highlightingMode), _quadPoints(other._quadPoints) {
     _actionOnActivation = (other._actionOnActivation ? other._actionOnActivation->clone() : nullptr);
   }
@@ -168,7 +174,7 @@ public:
     return *this;
   }
 
-  AnnotationType type() const { return AnnotationTypeLink; };
+  AnnotationType type() const override { return AnnotationTypeLink; }
 
   HighlightingMode highlightingMode() const { return _highlightingMode; }
   QPolygonF quadPoints() const;
@@ -179,22 +185,24 @@ public:
   // Note: Link takes ownership of PDFAction pointers
   void setActionOnActivation(PDFAction * const action);
 
+  bool operator==(const AbstractAnnotation & o) const override;
+
 private:
   // Note: the PA member of the link annotation dict is deliberately ommitted
   // because we don't support WebCapture at the moment
   // Note: The PDF specs include a "destination" field for LinkAnnotations;
   // In this implementation this case should be handled by a PDFGoToAction
-  HighlightingMode _highlightingMode;
+  HighlightingMode _highlightingMode{HighlightingNone};
   QPolygonF _quadPoints;
-  PDFAction * _actionOnActivation;
+  PDFAction * _actionOnActivation{nullptr};
 };
 
 class Text : public Markup
 {
 public:
-  AnnotationType type() const { return AnnotationTypeText; }
+  AnnotationType type() const override { return AnnotationTypeText; }
 private:
-  bool _open;
+  //bool _open;
   QString _iconName;
   QString _state;
   QString _stateModel;
@@ -203,14 +211,14 @@ private:
 class FreeText : public Markup
 {
 public:
-  AnnotationType type() const { return AnnotationTypeFreeText; }
+  AnnotationType type() const override { return AnnotationTypeFreeText; }
   // TODO: members
 };
 
 class Caret : public Markup
 {
 public:
-  AnnotationType type() const { return AnnotationTypeCaret; }
+  AnnotationType type() const override { return AnnotationTypeCaret; }
 private:
   QRectF _rectDiff;
   // enum _symbol;
@@ -219,44 +227,54 @@ private:
 class Popup : public AbstractAnnotation
 {
 public:
-  AnnotationType type() const { return AnnotationTypePopup; }
-  
+  AnnotationType type() const override { return AnnotationTypePopup; }
+
   Markup * parent() { return _parent; }
   bool isOpen() const { return _open; }
-  
+
   void setParent(Markup * parent) { _parent = parent; }
   void setOpen(const bool open = true) { _open = open; }
-  
+
+  QString contents() const override { return (_parent != nullptr ? _parent->contents() : _contents); }
+  QDateTime lastModified() const override { return (_parent != nullptr ? _parent->lastModified() : _lastModified); }
+  QColor color() const override { return (_parent != nullptr ? _parent->color() : _color); }
+  QString title() const { return (_parent != nullptr ? _parent->title() : _title); }
+
+  void setTitle(const QString & title) { _title = title; }
+
+  bool operator==(const AbstractAnnotation & o) const override;
+
 private:
-  Markup * _parent;
-  bool _open;
+  Markup * _parent{nullptr};
+  bool _open{false};
+  QString _title;
 };
 
 class Highlight : public Markup
 {
 public:
-  AnnotationType type() const { return AnnotationTypeHighlight; }
+  AnnotationType type() const override { return AnnotationTypeHighlight; }
   // TODO: members
 };
 
 class Underline: public Markup
 {
 public:
-  AnnotationType type() const { return AnnotationTypeUnderline; }
+  AnnotationType type() const override { return AnnotationTypeUnderline; }
   // TODO: members
 };
 
 class Squiggly: public Markup
 {
 public:
-  AnnotationType type() const { return AnnotationTypeSquiggly; }
+  AnnotationType type() const override { return AnnotationTypeSquiggly; }
   // TODO: members
 };
 
 class StrikeOut: public Markup
 {
 public:
-  AnnotationType type() const { return AnnotationTypeStrikeOut; }
+  AnnotationType type() const override { return AnnotationTypeStrikeOut; }
   // TODO: members
 };
 
