@@ -1,6 +1,39 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.1" language="ko_KR">
+<context>
+    <name>GuidelineEditDialog</name>
+    <message>
+        <location filename="../src/GuidelineEditDialog.ui" line="14"/>
+        <source>Edit guideline...</source>
+        <translation>안내선 수정...</translation>
+    </message>
+    <message>
+        <location filename="../src/GuidelineEditDialog.ui" line="22"/>
+        <source>Page:</source>
+        <translation>페이지:</translation>
+    </message>
+    <message>
+        <location filename="../src/GuidelineEditDialog.ui" line="36"/>
+        <source>Position:</source>
+        <translation>위치:</translation>
+    </message>
+    <message>
+        <location filename="../src/GuidelineEditDialog.ui" line="53"/>
+        <source>cm</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../src/GuidelineEditDialog.ui" line="58"/>
+        <source>in</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../src/GuidelineEditDialog.ui" line="63"/>
+        <source>bp</source>
+        <translation></translation>
+    </message>
+</context>
 <context>
     <name>PaperSize</name>
     <message>
@@ -719,50 +752,50 @@
 <context>
     <name>QtPDF</name>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="1269"/>
+        <location filename="../src/PDFDocumentView.cpp" line="33"/>
         <source>[language name]</source>
         <translation>한국어</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="1270"/>
+        <location filename="../src/PDFDocumentView.cpp" line="34"/>
         <source>[translator&apos;s name/email]</source>
-        <translation>Dohyun Kim&amp;lt;nomos@ktug.org&amp;gt;</translation>
+        <translation>Dohyun Kim&amp;lt;nomosnomos@gmail.com&amp;gt;</translation>
     </message>
 </context>
 <context>
     <name>QtPDF::PDFDocumentScene</name>
     <message>
-        <location filename="../src/PDFBackend.cpp" line="612"/>
+        <location filename="../src/PDFBackend.cpp" line="321"/>
         <source>rendering page</source>
         <translation>페이지 준비 중</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="2019"/>
+        <location filename="../src/PDFDocumentView.cpp" line="2013"/>
         <source>Unlock PDF</source>
         <translation>PDF 잠금 해제</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="2019"/>
+        <location filename="../src/PDFDocumentView.cpp" line="2013"/>
         <source>Please enter the password to unlock the PDF</source>
         <translation>PDF 잠금 해제를 위해 패스워드를 입력하세요</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="2035"/>
+        <location filename="../src/PDFDocumentView.cpp" line="2029"/>
         <source>Incorrect password</source>
         <translation>패스워드 오류</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="2035"/>
+        <location filename="../src/PDFDocumentView.cpp" line="2029"/>
         <source>The password you entered was incorrect.</source>
         <translation>패스워드를 잘못 입력하셨습니다.</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="2041"/>
+        <location filename="../src/PDFDocumentView.cpp" line="2035"/>
         <source>This document is locked. You need a password to open it.</source>
         <translation>문서가 잠겨 있습니다. 패스워드가 있어야 문서를 열 수 있습니다.</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="2042"/>
+        <location filename="../src/PDFDocumentView.cpp" line="2036"/>
         <source>Unlock</source>
         <translation>잠금 해제</translation>
     </message>
@@ -780,313 +813,313 @@
         <translation>이 문서는 텍스트 추출이 허용되지 않습니다.</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="2587"/>
+        <location filename="../src/PDFDocumentView.cpp" line="2577"/>
         <source>Goto page %1</source>
         <translation>%1쪽으로 가기</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="2599"/>
+        <location filename="../src/PDFDocumentView.cpp" line="2589"/>
         <source>Execute `%1`</source>
         <translation>`%1` 실행</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="2845"/>
-        <location filename="../src/PDFDocumentView.cpp" line="2862"/>
+        <location filename="../src/PDFDocumentView.cpp" line="2835"/>
+        <location filename="../src/PDFDocumentView.cpp" line="2852"/>
         <source>Table of Contents</source>
         <translation>차례</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="2954"/>
-        <location filename="../src/PDFDocumentView.cpp" line="3161"/>
+        <location filename="../src/PDFDocumentView.cpp" line="2944"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3151"/>
         <source>Meta Data</source>
         <translation>메타 정보</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3010"/>
-        <location filename="../src/PDFDocumentView.cpp" line="3171"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3000"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3161"/>
         <source>Processing</source>
         <translation>경과</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3042"/>
-        <location filename="../src/PDFDocumentView.cpp" line="3178"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3032"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3168"/>
         <source>Other</source>
         <translation>기타</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3105"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3095"/>
         <source>Yes</source>
         <translation>예</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3108"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3098"/>
         <source>No</source>
         <translation>아니오</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3111"/>
-        <location filename="../src/PDFDocumentView.cpp" line="3148"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3101"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3138"/>
         <source>Unknown</source>
         <translation>알 수 없음</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3163"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3153"/>
         <source>Document</source>
         <translation>문서</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3164"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3154"/>
         <source>Title:</source>
         <translation>제목:</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3165"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3155"/>
         <source>Author:</source>
         <translation>작성자:</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3166"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3156"/>
         <source>Subject:</source>
         <translation>주제:</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3167"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3157"/>
         <source>Keywords:</source>
         <translation>키워드:</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3172"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3162"/>
         <source>Creator:</source>
         <translation>작성 도구:</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3173"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3163"/>
         <source>Producer:</source>
         <translation>제작 도구:</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3174"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3164"/>
         <source>Creation date:</source>
         <translation>작성 날짜:</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3175"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3165"/>
         <source>Modification date:</source>
         <translation>수정 날짜:</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3176"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3166"/>
         <source>Trapped:</source>
         <translation>트랩됨:</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3187"/>
-        <location filename="../src/PDFDocumentView.cpp" line="3281"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3177"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3271"/>
         <source>Fonts</source>
         <translation>글꼴</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3237"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3227"/>
         <source>Type 0</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3240"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3230"/>
         <source>Type 1</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3243"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3233"/>
         <source>Type 1 (multiple master)</source>
         <translation>Type 1 (다중 마스터)</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3246"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3236"/>
         <source>Type 3</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3249"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3239"/>
         <source>TrueType</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3252"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3242"/>
         <source>yes</source>
         <translation>예</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3252"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3242"/>
         <source>no</source>
         <translation>아니오</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3255"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3245"/>
         <source>[embedded]</source>
         <translation>[내장됨]</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3258"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3248"/>
         <source>[builtin]</source>
         <translation>[내장]</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3282"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3272"/>
         <source>Name</source>
         <translation>이름</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3282"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3272"/>
         <source>Type</source>
         <translation>유형</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3282"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3272"/>
         <source>Subset</source>
         <translation>서브셋</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3282"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3272"/>
         <source>Source</source>
         <translation>위치</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3290"/>
-        <location filename="../src/PDFDocumentView.cpp" line="3385"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3280"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3375"/>
         <source>Permissions</source>
         <translation>권한</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3339"/>
-        <location filename="../src/PDFDocumentView.cpp" line="3348"/>
-        <location filename="../src/PDFDocumentView.cpp" line="3357"/>
-        <location filename="../src/PDFDocumentView.cpp" line="3364"/>
-        <location filename="../src/PDFDocumentView.cpp" line="3369"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3329"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3338"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3347"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3354"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3359"/>
         <source>Allowed</source>
         <translation>허용됨</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3341"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3331"/>
         <source>Low resolution only</source>
         <translation>저해상도만 허용</translation>
     </message>
     <message>
+        <location filename="../src/PDFDocumentView.cpp" line="3334"/>
         <location filename="../src/PDFDocumentView.cpp" line="3344"/>
-        <location filename="../src/PDFDocumentView.cpp" line="3354"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3351"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3356"/>
         <location filename="../src/PDFDocumentView.cpp" line="3361"/>
         <location filename="../src/PDFDocumentView.cpp" line="3366"/>
-        <location filename="../src/PDFDocumentView.cpp" line="3371"/>
-        <location filename="../src/PDFDocumentView.cpp" line="3376"/>
-        <location filename="../src/PDFDocumentView.cpp" line="3377"/>
-        <location filename="../src/PDFDocumentView.cpp" line="3378"/>
-        <location filename="../src/PDFDocumentView.cpp" line="3379"/>
-        <location filename="../src/PDFDocumentView.cpp" line="3380"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3367"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3368"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3369"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3370"/>
         <source>Denied</source>
         <translation>허용 안됨</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3350"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3340"/>
         <source>Assembling only</source>
         <translation>어셈블리만 허용</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3351"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3341"/>
         <source>Insert, rotate, or delete pages and create bookmarks or thumbnail images</source>
         <translation>페이지 삽입·회전·삭제 및 북마크·썸네일 넣기</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3359"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3349"/>
         <source>Accessibility support only</source>
         <translation>접근성 지원만 허용</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3387"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3377"/>
         <source>Printing:</source>
         <translation>인쇄:</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3388"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3378"/>
         <source>Modifications:</source>
         <translation>내용 변경:</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3389"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3379"/>
         <source>Extraction:</source>
         <translation>텍스트 추출:</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3390"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3380"/>
         <source>Annotation:</source>
         <translation>주석 달기:</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3391"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3381"/>
         <source>Filling forms:</source>
         <translation>양식 채우기:</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3399"/>
-        <location filename="../src/PDFDocumentView.cpp" line="3491"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3389"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3481"/>
         <source>Annotations</source>
         <translation>주석</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3492"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3482"/>
         <source>Page</source>
         <translation>쪽</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3492"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3482"/>
         <source>Subject</source>
         <translation>이름</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3492"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3482"/>
         <source>Author</source>
         <translation>작성자</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3492"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3482"/>
         <source>Contents</source>
         <translation>내용</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3067"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3057"/>
         <source>B</source>
         <extracomment>File size: bytes</extracomment>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3069"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3059"/>
         <source>kB</source>
         <extracomment>File size: kilobytes</extracomment>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3071"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3061"/>
         <source>MB</source>
         <extracomment>File size: megabytes</extracomment>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3073"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3063"/>
         <source>GB</source>
         <extracomment>File size: gigabytes</extracomment>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3075"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3065"/>
         <source>TB</source>
         <extracomment>File size: terabytes</extracomment>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3168"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3158"/>
         <source>Page size:</source>
         <translation>쪽 크기:</translation>
     </message>
     <message>
-        <location filename="../src/PDFDocumentView.cpp" line="3169"/>
+        <location filename="../src/PDFDocumentView.cpp" line="3159"/>
         <source>File size:</source>
         <translation>파일 크기:</translation>
     </message>
