@@ -1,6 +1,6 @@
 /*
 	This is part of TeXworks, an environment for working with TeX documents
-	Copyright (C) 2007-2016  Jonathan Kew, Stefan Löffler, Charlie Sharpsteen
+	Copyright (C) 2007-2022  Jonathan Kew, Stefan Löffler, Charlie Sharpsteen
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -20,20 +20,20 @@
 */
 
 #include "FindDialog.h"
-#include "TeXDocument.h"
-#include "PDFDocument.h"
+#include "PDFDocumentWindow.h"
+#include "Settings.h"
 #include "TWApp.h"
+#include "TeXDocumentWindow.h"
 
-#include <QPushButton>
-#include <QTableWidget>
-#include <QHeaderView>
-#include <QTextBlock>
 #include <QFileInfo>
+#include <QHeaderView>
 #include <QKeyEvent>
+#include <QPointer>
+#include <QPushButton>
 #include <QShortcut>
-#if QT_VERSION >= 0x040400
+#include <QTableWidget>
+#include <QTextBlock>
 #include <QTextBoundaryFinder>
-#endif
 
 const int kMaxRecentStrings = 10;
 
@@ -46,7 +46,7 @@ FindDialog::FindDialog(QTextEdit *parent)
 bool RecentStringsKeyFilter::eventFilter(QObject *obj, QEvent *event)
 {
 	if (event->type() == QEvent::KeyPress) {
-		QKeyEvent *e = static_cast<QKeyEvent*>(event);
+		QKeyEvent *e = dynamic_cast<QKeyEvent*>(event);
 		Qt::KeyboardModifiers mods = e->modifiers();
 		if ((mods & Qt::ControlModifier) != Qt::NoModifier) {
 			if (e->key() == Qt::Key_Up) {
@@ -69,11 +69,11 @@ void RecentStringsKeyFilter::setRecentString(QObject *obj, int dir)
 	QLineEdit *lineEdit = qobject_cast<QLineEdit*>(obj);
 	if (!lineEdit)
 		return;
-	
+
 	if (strings.empty())
 		return;
-	
-	int index = strings.indexOf(lineEdit->text());
+
+	QStringList::size_type index = strings.indexOf(lineEdit->text());
 	if (index == -1)
 		index = (dir == 1) ? 0 : strings.size() - 1;
 	else {
@@ -83,7 +83,7 @@ void RecentStringsKeyFilter::setRecentString(QObject *obj, int dir)
 		else if (index >= strings.size())
 			index = 0;
 	}
-	
+
 	lineEdit->setText(strings[index]);
 	lineEdit->selectAll();
 }
@@ -94,49 +94,49 @@ void FindDialog::init(QTextEdit *document)
 
 	buttonBox->button(QDialogButtonBox::Ok)->setText(tr("Find"));
 
-	connect(checkBox_allFiles, SIGNAL(toggled(bool)), this, SLOT(toggledAllFilesOption(bool)));
-	connect(checkBox_findAll, SIGNAL(toggled(bool)), this, SLOT(toggledFindAllOption(bool)));
-	connect(checkBox_regex, SIGNAL(toggled(bool)), this, SLOT(toggledRegexOption(bool)));
-	connect(checkBox_selection, SIGNAL(toggled(bool)), this, SLOT(toggledSelectionOption(bool)));
-	connect(searchText, SIGNAL(textChanged(const QString&)), this, SLOT(checkRegex(const QString&)));
+	connect(checkBox_allFiles, &QCheckBox::toggled, this, &FindDialog::toggledAllFilesOption);
+	connect(checkBox_findAll, &QCheckBox::toggled, this, &FindDialog::toggledFindAllOption);
+	connect(checkBox_regex, &QCheckBox::toggled, this, &FindDialog::toggledRegexOption);
+	connect(checkBox_selection, &QCheckBox::toggled, this, &FindDialog::toggledSelectionOption);
+	connect(searchText, &QLineEdit::textChanged, this, &FindDialog::checkRegex);
 
-	QSETTINGS_OBJECT(settings);
-	QString	str = settings.value("searchText").toString();
+	Tw::Settings settings;
+	QString	str = settings.value(QString::fromLatin1("searchText")).toString();
 	searchText->setText(str);
 	searchText->selectAll();
 
-	bool regexOption = settings.value("searchRegex").toBool();
+	bool regexOption = settings.value(QString::fromLatin1("searchRegex")).toBool();
 	checkBox_regex->setChecked(regexOption);
 	checkBox_words->setEnabled(!regexOption);
 
-	bool findAll = settings.value("searchFindAll").toBool();
+	bool findAll = settings.value(QString::fromLatin1("searchFindAll")).toBool();
 	checkBox_findAll->setChecked(findAll);
-	
-	bool allFiles = settings.value("searchAllFiles").toBool();
-	checkBox_allFiles->setEnabled(TeXDocument::documentList().count() > 1);
+
+	bool allFiles = settings.value(QString::fromLatin1("searchAllFiles")).toBool();
+	checkBox_allFiles->setEnabled(TeXDocumentWindow::documentList().count() > 1);
 	checkBox_allFiles->setChecked(allFiles && checkBox_allFiles->isEnabled());
 
-	bool selectionOption = settings.value("searchSelection").toBool();
+	bool selectionOption = settings.value(QString::fromLatin1("searchSelection")).toBool();
 	checkBox_selection->setEnabled(document->textCursor().hasSelection() && !findAll);
 	checkBox_selection->setChecked(selectionOption && checkBox_selection->isEnabled());
 
-	bool wrapOption = settings.value("searchWrap").toBool();
+	bool wrapOption = settings.value(QString::fromLatin1("searchWrap")).toBool();
 	checkBox_wrap->setEnabled(!(checkBox_selection->isEnabled() && checkBox_selection->isChecked()) && !findAll);
 	checkBox_wrap->setChecked(wrapOption);
 
-	QTextDocument::FindFlags flags = (QTextDocument::FindFlags)settings.value("searchFlags").toInt();
+	QTextDocument::FindFlags flags = static_cast<QTextDocument::FindFlags>(settings.value(QString::fromLatin1("searchFlags")).toInt());
 	checkBox_case->setChecked((flags & QTextDocument::FindCaseSensitively) != 0);
 	checkBox_words->setChecked((flags & QTextDocument::FindWholeWords) != 0);
 	checkBox_backwards->setChecked((flags & QTextDocument::FindBackward) != 0);
 	checkBox_backwards->setEnabled(!findAll);
-	
+
 	QMenu *recentItemsMenu = new QMenu(this);
-	QStringList recentStrings = settings.value("recentSearchStrings").toStringList();
-	if (recentStrings.size() == 0)
+	QStringList recentStrings = settings.value(QString::fromLatin1("recentSearchStrings")).toStringList();
+	if (recentStrings.empty())
 		recentItemsMenu->addAction(tr("No recent search strings"))->setEnabled(false);
 	else {
 		foreach (const QString& str, recentStrings)
-			connect(recentItemsMenu->addAction(str), SIGNAL(triggered()), this, SLOT(setSearchText()));
+			connect(recentItemsMenu->addAction(str), &QAction::triggered, this, &FindDialog::setSearchText);
 	}
 	recentSearches->setMenu(recentItemsMenu);
 	searchText->installEventFilter(new RecentStringsKeyFilter(this, recentStrings));
@@ -145,7 +145,7 @@ void FindDialog::init(QTextEdit *document)
 void FindDialog::setSearchText()
 {
 	QAction *act = qobject_cast<QAction*>(sender());
-	if (act != NULL) {
+	if (act) {
 		searchText->setText(act->text());
 		searchText->selectAll();
 	}
@@ -154,7 +154,7 @@ void FindDialog::setSearchText()
 void FindDialog::toggledAllFilesOption(bool checked)
 {
 	QTextEdit* document = qobject_cast<QTextEdit*>(parent());
-	checkBox_selection->setEnabled(document != NULL && document->textCursor().hasSelection() && !checked && !checkBox_findAll->isChecked());
+	checkBox_selection->setEnabled(document && document->textCursor().hasSelection() && !checked && !checkBox_findAll->isChecked());
 	checkBox_wrap->setEnabled(!(checkBox_selection->isEnabled() && checkBox_selection->isChecked()) && !checked && !checkBox_findAll->isChecked());
 	checkBox_backwards->setEnabled(!checked && !checkBox_findAll->isChecked());
 	checkBox_findAll->setEnabled(!checked);
@@ -163,7 +163,7 @@ void FindDialog::toggledAllFilesOption(bool checked)
 void FindDialog::toggledFindAllOption(bool checked)
 {
 	QTextEdit* document = qobject_cast<QTextEdit*>(parent());
-	checkBox_selection->setEnabled(document != NULL && document->textCursor().hasSelection() && !checked);
+	checkBox_selection->setEnabled(document && document->textCursor().hasSelection() && !checked);
 	checkBox_wrap->setEnabled(!(checkBox_selection->isEnabled() && checkBox_selection->isChecked()) && !checked);
 	checkBox_backwards->setEnabled(!checked);
 }
@@ -174,7 +174,7 @@ void FindDialog::toggledRegexOption(bool checked)
 	if (checked)
 		checkRegex(searchText->text());
 	else
-		regexStatus->setText("");
+		regexStatus->setText(QString());
 }
 
 void FindDialog::toggledSelectionOption(bool checked)
@@ -185,9 +185,9 @@ void FindDialog::toggledSelectionOption(bool checked)
 void FindDialog::checkRegex(const QString& str)
 {
 	if (checkBox_regex->isChecked()) {
-		QRegExp regex(str);
+		QRegularExpression regex(str);
 		if (regex.isValid())
-			regexStatus->setText("");
+			regexStatus->setText(QString());
 		else
 			regexStatus->setText(tr("(invalid)"));
 	}
@@ -198,19 +198,19 @@ QDialog::DialogCode FindDialog::doFindDialog(QTextEdit *document)
 	FindDialog dlg(document);
 
 	dlg.show();
-	DialogCode	result = (DialogCode)dlg.exec();
-	
+	DialogCode result = static_cast<DialogCode>(dlg.exec());
+
 	if (result == Accepted) {
-		QSETTINGS_OBJECT(settings);
+		Tw::Settings settings;
 		QString str = dlg.searchText->text();
-		settings.setValue("searchText", str);
-		
-		QStringList recentStrings = settings.value("recentSearchStrings").toStringList();
+		settings.setValue(QString::fromLatin1("searchText"), str);
+
+		QStringList recentStrings = settings.value(QString::fromLatin1("recentSearchStrings")).toStringList();
 		recentStrings.removeAll(str);
 		recentStrings.prepend(str);
 		while (recentStrings.count() > kMaxRecentStrings)
 			recentStrings.removeLast();
-		settings.setValue("recentSearchStrings", recentStrings);
+		settings.setValue(QString::fromLatin1("recentSearchStrings"), recentStrings);
 
 		int flags = 0;
 		if (dlg.checkBox_case->isChecked())
@@ -219,13 +219,13 @@ QDialog::DialogCode FindDialog::doFindDialog(QTextEdit *document)
 			flags |= QTextDocument::FindWholeWords;
 		if (dlg.checkBox_backwards->isChecked())
 			flags |= QTextDocument::FindBackward;
-		settings.setValue("searchFlags", (int)flags);
+		settings.setValue(QString::fromLatin1("searchFlags"), static_cast<int>(flags));
 
-		settings.setValue("searchRegex", dlg.checkBox_regex->isChecked());
-		settings.setValue("searchWrap", dlg.checkBox_wrap->isChecked());
-		settings.setValue("searchSelection", dlg.checkBox_selection->isChecked());
-		settings.setValue("searchFindAll", dlg.checkBox_findAll->isChecked());
-		settings.setValue("searchAllFiles", dlg.checkBox_allFiles->isChecked());
+		settings.setValue(QString::fromLatin1("searchRegex"), dlg.checkBox_regex->isChecked());
+		settings.setValue(QString::fromLatin1("searchWrap"), dlg.checkBox_wrap->isChecked());
+		settings.setValue(QString::fromLatin1("searchSelection"), dlg.checkBox_selection->isChecked());
+		settings.setValue(QString::fromLatin1("searchFindAll"), dlg.checkBox_findAll->isChecked());
+		settings.setValue(QString::fromLatin1("searchAllFiles"), dlg.checkBox_allFiles->isChecked());
 	}
 
 	return result;
@@ -241,66 +241,66 @@ void ReplaceDialog::init(QTextEdit *document)
 {
 	setupUi(this);
 
-	connect(checkBox_allFiles, SIGNAL(toggled(bool)), this, SLOT(toggledAllFilesOption(bool)));
-	connect(checkBox_regex, SIGNAL(toggled(bool)), this, SLOT(toggledRegexOption(bool)));
-	connect(checkBox_selection, SIGNAL(toggled(bool)), this, SLOT(toggledSelectionOption(bool)));
-	connect(searchText, SIGNAL(textChanged(const QString&)), this, SLOT(checkRegex(const QString&)));
+	connect(checkBox_allFiles, &QCheckBox::toggled, this, &ReplaceDialog::toggledAllFilesOption);
+	connect(checkBox_regex, &QCheckBox::toggled, this, &ReplaceDialog::toggledRegexOption);
+	connect(checkBox_selection, &QCheckBox::toggled, this, &ReplaceDialog::toggledSelectionOption);
+	connect(searchText, &QLineEdit::textChanged, this, &ReplaceDialog::checkRegex);
 
 	// using "standard" buttons then changing the labels means that Qt can reorder them appropriately for the platform
 	// whereas if we just put our own named buttons in place manually, they'd always stay in the same order
 	buttonBox->button(QDialogButtonBox::Ok)->setText(tr("Replace"));
-	connect(buttonBox->button(QDialogButtonBox::Ok), SIGNAL(clicked()), this, SLOT(clickedReplace()));
+	connect(buttonBox->button(QDialogButtonBox::Ok), &QPushButton::clicked, this, &ReplaceDialog::clickedReplace);
 	buttonBox->button(QDialogButtonBox::SaveAll)->setText(tr("Replace All"));
-	connect(buttonBox->button(QDialogButtonBox::SaveAll), SIGNAL(clicked()), this, SLOT(clickedReplaceAll()));
+	connect(buttonBox->button(QDialogButtonBox::SaveAll), &QPushButton::clicked, this, &ReplaceDialog::clickedReplaceAll);
 	buttonBox->button(QDialogButtonBox::Cancel)->setText(tr("Cancel"));
-	connect(buttonBox->button(QDialogButtonBox::Cancel), SIGNAL(clicked()), this, SLOT(reject()));
+	connect(buttonBox->button(QDialogButtonBox::Cancel), &QPushButton::clicked, this, &ReplaceDialog::reject);
 
-	QSETTINGS_OBJECT(settings);
-	QString	str = settings.value("searchText").toString();
+	Tw::Settings settings;
+	QString	str = settings.value(QString::fromLatin1("searchText")).toString();
 	searchText->setText(str);
 	searchText->selectAll();
-	str = settings.value("replaceText").toString();
+	str = settings.value(QString::fromLatin1("replaceText")).toString();
 	replaceText->setText(str);
 
-	bool regexOption = settings.value("searchRegex").toBool();
+	bool regexOption = settings.value(QString::fromLatin1("searchRegex")).toBool();
 	checkBox_regex->setChecked(regexOption);
 	checkBox_words->setEnabled(!regexOption);
 
-	bool allFiles = settings.value("searchAllFiles").toBool();
-	checkBox_allFiles->setEnabled(TeXDocument::documentList().count() > 1);
+	bool allFiles = settings.value(QString::fromLatin1("searchAllFiles")).toBool();
+	checkBox_allFiles->setEnabled(TeXDocumentWindow::documentList().count() > 1);
 	checkBox_allFiles->setChecked(allFiles && checkBox_allFiles->isEnabled());
 
-	bool selectionOption = settings.value("searchSelection").toBool();
+	bool selectionOption = settings.value(QString::fromLatin1("searchSelection")).toBool();
 	checkBox_selection->setEnabled(document->textCursor().hasSelection());
 	checkBox_selection->setChecked(selectionOption && checkBox_selection->isEnabled());
 
-	bool wrapOption = settings.value("searchWrap").toBool();
+	bool wrapOption = settings.value(QString::fromLatin1("searchWrap")).toBool();
 	checkBox_wrap->setEnabled(!(checkBox_selection->isEnabled() && checkBox_selection->isChecked()));
 	checkBox_wrap->setChecked(wrapOption);
 
-	QTextDocument::FindFlags flags = (QTextDocument::FindFlags)settings.value("searchFlags").toInt();
+	QTextDocument::FindFlags flags = static_cast<QTextDocument::FindFlags>(settings.value(QString::fromLatin1("searchFlags")).toInt());
 	checkBox_case->setChecked((flags & QTextDocument::FindCaseSensitively) != 0);
 	checkBox_words->setChecked((flags & QTextDocument::FindWholeWords) != 0);
 	checkBox_backwards->setChecked((flags & QTextDocument::FindBackward) != 0);
 
 	QMenu *recentItemsMenu = new QMenu(this);
-	QStringList recentStrings = settings.value("recentSearchStrings").toStringList();
-	if (recentStrings.size() == 0)
+	QStringList recentStrings = settings.value(QString::fromLatin1("recentSearchStrings")).toStringList();
+	if (recentStrings.empty())
 		recentItemsMenu->addAction(tr("No recent search strings"))->setEnabled(false);
 	else {
 		foreach (const QString& str, recentStrings)
-			connect(recentItemsMenu->addAction(str), SIGNAL(triggered()), this, SLOT(setSearchText()));
+			connect(recentItemsMenu->addAction(str), &QAction::triggered, this, &ReplaceDialog::setSearchText);
 	}
 	recentSearches->setMenu(recentItemsMenu);
 	searchText->installEventFilter(new RecentStringsKeyFilter(this, recentStrings));
 
 	recentItemsMenu = new QMenu(this);
-	recentStrings = settings.value("recentReplaceStrings").toStringList();
-	if (recentStrings.size() == 0)
+	recentStrings = settings.value(QString::fromLatin1("recentReplaceStrings")).toStringList();
+	if (recentStrings.empty())
 		recentItemsMenu->addAction(tr("No recent replacement strings"))->setEnabled(false);
 	else {
 		foreach (const QString& str, recentStrings)
-			connect(recentItemsMenu->addAction(str), SIGNAL(triggered()), this, SLOT(setReplaceText()));
+			connect(recentItemsMenu->addAction(str), &QAction::triggered, this, &ReplaceDialog::setReplaceText);
 	}
 	recentReplacements->setMenu(recentItemsMenu);
 	replaceText->installEventFilter(new RecentStringsKeyFilter(this, recentStrings));
@@ -309,7 +309,7 @@ void ReplaceDialog::init(QTextEdit *document)
 void ReplaceDialog::setSearchText()
 {
 	QAction *act = qobject_cast<QAction*>(sender());
-	if (act != NULL) {
+	if (act) {
 		searchText->setText(act->text());
 		searchText->selectAll();
 	}
@@ -318,7 +318,7 @@ void ReplaceDialog::setSearchText()
 void ReplaceDialog::setReplaceText()
 {
 	QAction *act = qobject_cast<QAction*>(sender());
-	if (act != NULL) {
+	if (act) {
 		replaceText->setText(act->text());
 		replaceText->selectAll();
 	}
@@ -327,7 +327,7 @@ void ReplaceDialog::setReplaceText()
 void ReplaceDialog::toggledAllFilesOption(bool checked)
 {
 	QTextEdit* document = qobject_cast<QTextEdit*>(parent());
-	checkBox_selection->setEnabled(document != NULL && document->textCursor().hasSelection() && !checked);
+	checkBox_selection->setEnabled(document && document->textCursor().hasSelection() && !checked);
 	checkBox_wrap->setEnabled(!(checkBox_selection->isEnabled() && checkBox_selection->isChecked()) && !checked);
 	checkBox_backwards->setEnabled(!checked);
 	buttonBox->button(QDialogButtonBox::Ok)->setEnabled(!checked);
@@ -339,7 +339,7 @@ void ReplaceDialog::toggledRegexOption(bool checked)
 	if (checked)
 		checkRegex(searchText->text());
 	else
-		regexStatus->setText("");
+		regexStatus->setText(QString());
 }
 
 void ReplaceDialog::toggledSelectionOption(bool checked)
@@ -350,9 +350,9 @@ void ReplaceDialog::toggledSelectionOption(bool checked)
 void ReplaceDialog::checkRegex(const QString& str)
 {
 	if (checkBox_regex->isChecked()) {
-		QRegExp regex(str);
+		QRegularExpression regex(str);
 		if (regex.isValid())
-			regexStatus->setText("");
+			regexStatus->setText(QString());
 		else
 			regexStatus->setText(tr("(invalid)"));
 	}
@@ -377,44 +377,43 @@ ReplaceDialog::DialogCode ReplaceDialog::doReplaceDialog(QTextEdit *document)
 
 	if (result == 0)
 		return Cancel;
-	else {
-		QSETTINGS_OBJECT(settings);
-		QString str = dlg.searchText->text();
-		settings.setValue("searchText", str);
-		
-		QStringList recentStrings = settings.value("recentSearchStrings").toStringList();
-		recentStrings.removeAll(str);
-		recentStrings.prepend(str);
-		while (recentStrings.count() > kMaxRecentStrings)
-			recentStrings.removeLast();
-		settings.setValue("recentSearchStrings", recentStrings);
-		
-		str = dlg.replaceText->text();
-		settings.setValue("replaceText", str);
 
-		recentStrings = settings.value("recentReplaceStrings").toStringList();
-		recentStrings.removeAll(str);
-		recentStrings.prepend(str);
-		while (recentStrings.count() > kMaxRecentStrings)
-			recentStrings.removeLast();
-		settings.setValue("recentReplaceStrings", recentStrings);
-		
-		int flags = 0;
-		if (dlg.checkBox_case->isChecked())
-			flags |= QTextDocument::FindCaseSensitively;
-		if (dlg.checkBox_words->isChecked())
-			flags |= QTextDocument::FindWholeWords;
-		if (dlg.checkBox_backwards->isChecked())
-			flags |= QTextDocument::FindBackward;
-		settings.setValue("searchFlags", (int)flags);
+	Tw::Settings settings;
+	QString str = dlg.searchText->text();
+	settings.setValue(QString::fromLatin1("searchText"), str);
 
-		settings.setValue("searchRegex", dlg.checkBox_regex->isChecked());
-		settings.setValue("searchWrap", dlg.checkBox_wrap->isChecked());
-		settings.setValue("searchSelection", dlg.checkBox_selection->isChecked());
-		settings.setValue("searchAllFiles", dlg.checkBox_allFiles->isChecked());
+	QStringList recentStrings = settings.value(QString::fromLatin1("recentSearchStrings")).toStringList();
+	recentStrings.removeAll(str);
+	recentStrings.prepend(str);
+	while (recentStrings.count() > kMaxRecentStrings)
+		recentStrings.removeLast();
+	settings.setValue(QString::fromLatin1("recentSearchStrings"), recentStrings);
 
-		return (result == 2) ? ReplaceAll : ReplaceOne;
-	}
+	str = dlg.replaceText->text();
+	settings.setValue(QString::fromLatin1("replaceText"), str);
+
+	recentStrings = settings.value(QString::fromLatin1("recentReplaceStrings")).toStringList();
+	recentStrings.removeAll(str);
+	recentStrings.prepend(str);
+	while (recentStrings.count() > kMaxRecentStrings)
+		recentStrings.removeLast();
+	settings.setValue(QString::fromLatin1("recentReplaceStrings"), recentStrings);
+
+	int flags = 0;
+	if (dlg.checkBox_case->isChecked())
+		flags |= QTextDocument::FindCaseSensitively;
+	if (dlg.checkBox_words->isChecked())
+		flags |= QTextDocument::FindWholeWords;
+	if (dlg.checkBox_backwards->isChecked())
+		flags |= QTextDocument::FindBackward;
+	settings.setValue(QString::fromLatin1("searchFlags"), static_cast<int>(flags));
+
+	settings.setValue(QString::fromLatin1("searchRegex"), dlg.checkBox_regex->isChecked());
+	settings.setValue(QString::fromLatin1("searchWrap"), dlg.checkBox_wrap->isChecked());
+	settings.setValue(QString::fromLatin1("searchSelection"), dlg.checkBox_selection->isChecked());
+	settings.setValue(QString::fromLatin1("searchAllFiles"), dlg.checkBox_allFiles->isChecked());
+
+	return (result == 2) ? ReplaceAll : ReplaceOne;
 }
 
 
@@ -422,42 +421,22 @@ SearchResults::SearchResults(QWidget* parent)
 	: QDockWidget(parent)
 {
 	setupUi(this);
-	connect(table, SIGNAL(itemSelectionChanged()), this, SLOT(showSelectedEntry()));
-	connect(table, SIGNAL(itemPressed(QTableWidgetItem*)), this, SLOT(showEntry(QTableWidgetItem*)));
-	connect(table, SIGNAL(itemActivated(QTableWidgetItem*)), this, SLOT(goToSource()));
-	QShortcut *sc;
-	sc = new QShortcut(Qt::Key_Escape, table);
+	setFocusProxy(parent);
+	connect(table, &QTableWidget::itemSelectionChanged, this, &SearchResults::showSelectedEntry);
+	connect(table, &QTableWidget::itemPressed, this, &SearchResults::showEntry);
+	connect(table, &QTableWidget::itemActivated, this, &SearchResults::goToSource);
+	QShortcut * sc = new QShortcut(Qt::Key_Escape, table);
 	sc->setContext(Qt::WidgetShortcut);
-	connect(sc, SIGNAL(activated()), this, SLOT(goToSourceAndClose()));
-	
-	TeXDocument * texDoc = qobject_cast<TeXDocument*>(parent);
-	if (texDoc) {
-		editorModifiedPalette = editorOriginalPalette = texDoc->palette();
-		editorModifiedPalette.setColor(QPalette::Highlight, editorOriginalPalette.color(QPalette::Active, QPalette::Highlight));
-		editorModifiedPalette.setColor(QPalette::HighlightedText, editorOriginalPalette.color(QPalette::Active, QPalette::HighlightedText));
-	}
-	connect(TWApp::instance(), SIGNAL(focusChanged(QWidget*,QWidget*)), this, SLOT(focusChanged(QWidget*,QWidget*)));
+	connect(sc, &QShortcut::activated, this, &SearchResults::goToSourceAndClose);
 }
 
 void SearchResults::goToSource()
 {
-	QList<QTableWidgetSelectionRange> ranges = table->selectedRanges();
-	if (ranges.count() == 0)
-		return;
-	int row = ranges.first().topRow();
-	QString fileName;
-	QTableWidgetItem* item = table->item(row, 0);
-	if (!item)
-		return;
-	fileName = item->toolTip();
-	
-	if (!fileName.isEmpty()) {
-		QWidget *theDoc = TeXDocument::openDocument(fileName);
-		if (theDoc) {
-			QTextEdit *editor = theDoc->findChild<QTextEdit*>("textEdit");
-			if (editor)
-				editor->setFocus();
-		}
+	TeXDocumentWindow * theDoc = showSelectedEntry();
+	if (theDoc) {
+		QTextEdit * editor = theDoc->findChild<QTextEdit*>(QString::fromLatin1("textEdit"));
+		if (editor)
+			editor->setFocus();
 	}
 }
 
@@ -489,8 +468,18 @@ void SearchResults::presentResults(const QString& searchText,
 	resultsWindow->table->setRowCount(results.count());
 	int i = 0;
 	foreach (const SearchResult &result, results) {
-		QTableWidgetItem *item = new QTableWidgetItem(QFileInfo(result.doc->fileName()).fileName());
+		QTableWidgetItem * item = new QTableWidgetItem();
+		if (result.doc->untitled()) {
+			item->setText(QFileInfo(result.doc->fileName()).fileName() + QStringLiteral("*"));
+			QFont f = item->font();
+			f.setItalic(true);
+			item->setFont(f);
+		}
+		else {
+			item->setText(QFileInfo(result.doc->fileName()).fileName());
+		}
 		item->setToolTip(result.doc->fileName());
+		item->setData(Qt::UserRole, QVariant::fromValue(QPointer<TeXDocumentWindow>(result.doc)));
 		resultsWindow->table->setItem(i, 0, item);
 		resultsWindow->table->setItem(i, 1, new QTableWidgetItem(QString::number(result.lineNo)));
 		resultsWindow->table->setItem(i, 2, new QTableWidgetItem(QString::number(result.selStart)));
@@ -499,10 +488,9 @@ void SearchResults::presentResults(const QString& searchText,
 		// Only show a limited number of characters before and after the
 		// specified search string to keep the results clear
 		bool truncateStart = true, truncateEnd = true;
-		int iStart, iEnd;
 		QString text = result.doc->getLineText(result.lineNo);
-		iStart = result.selStart - MAXIMUM_CHARACTERS_BEFORE_SEARCH_RESULT;
-		iEnd = result.selEnd + MAXIMUM_CHARACTERS_AFTER_SEARCH_RESULT;
+		QString::size_type iStart = result.selStart - MAXIMUM_CHARACTERS_BEFORE_SEARCH_RESULT;
+		QString::size_type iEnd = result.selEnd + MAXIMUM_CHARACTERS_AFTER_SEARCH_RESULT;
 		if (iStart < 0) {
 			iStart = 0;
 			truncateStart = false;
@@ -511,7 +499,6 @@ void SearchResults::presentResults(const QString& searchText,
 			iEnd = text.length();
 			truncateEnd = false;
 		}
-#if QT_VERSION >= 0x040400 // QTextBoundaryFinder is new in Qt 4.4
 		if (truncateStart || truncateEnd) {
 			// ensure the truncation happens on appropriate boundaries, not mid-cluster
 			QTextBoundaryFinder tbf(QTextBoundaryFinder::Grapheme, text);
@@ -530,7 +517,6 @@ void SearchResults::presentResults(const QString& searchText,
 				}
 			}
 		}
-#endif
 		text = text.mid(iStart, iEnd - iStart);
 		if (truncateStart)
 			text.prepend(tr("..."));
@@ -542,13 +528,8 @@ void SearchResults::presentResults(const QString& searchText,
 	}
 
 	resultsWindow->table->setHorizontalHeaderLabels(QStringList() << tr("File") << tr("Line") << tr("Start") << tr("End") << tr("Text"));
-	#if QT_VERSION >= 0x050000
 	resultsWindow->table->horizontalHeader()->setSectionResizeMode(4, QHeaderView::Stretch);
 	resultsWindow->table->verticalHeader()->setSectionResizeMode(QHeaderView::ResizeToContents);
-	#else
-	resultsWindow->table->horizontalHeader()->setResizeMode(4, QHeaderView::Stretch);
-	resultsWindow->table->verticalHeader()->setResizeMode(QHeaderView::ResizeToContents);
-	#endif
 	resultsWindow->table->verticalHeader()->hide();
 	resultsWindow->table->setColumnHidden(2, true);
 	resultsWindow->table->setColumnHidden(3, true);
@@ -564,20 +545,21 @@ void SearchResults::presentResults(const QString& searchText,
 	else {
 		resultsWindow->setAllowedAreas(Qt::NoDockWidgetArea);
 		resultsWindow->setFeatures(QDockWidget::NoDockWidgetFeatures);
-		resultsWindow->setParent(NULL);
+		resultsWindow->setParent(nullptr);
 		resultsWindow->setWindowFlags(Qt::Window | Qt::WindowStaysOnTopHint);
 	}
-	
+
 	resultsWindow->show();
 }
 
-void SearchResults::showEntry(QTableWidgetItem * item)
+TeXDocumentWindow * SearchResults::showEntry(QTableWidgetItem * item)
 {
 	if (!item)
-		return;
+		return nullptr;
 	int row = item->row();
 	item = table->item(row, 0);
 	QString fileName = item->toolTip();
+	QPointer<TeXDocumentWindow> texDoc = item->data(Qt::UserRole).value< QPointer<TeXDocumentWindow> >();
 	item = table->item(row, 1);
 	int lineNo = item->text().toInt();
 	item = table->item(row, 2);
@@ -585,83 +567,67 @@ void SearchResults::showEntry(QTableWidgetItem * item)
 	item = table->item(row, 3);
 	int selEnd = item->text().toInt();
 
+	if (texDoc) {
+		texDoc->show();
+		texDoc->raise();
+		if (texDoc->isMinimized()) {
+			texDoc->showNormal();
+		}
+		texDoc->goToLine(lineNo, selStart, selEnd);
+		return texDoc;
+	}
 	if (!fileName.isEmpty())
-		TeXDocument::openDocument(fileName, false, true, lineNo, selStart, selEnd);
+		return TeXDocumentWindow::openDocument(fileName, false, true, lineNo, selStart, selEnd);
+	return nullptr;
 }
 
-void SearchResults::showSelectedEntry()
+TeXDocumentWindow * SearchResults::showSelectedEntry()
 {
 	QList<QTableWidgetSelectionRange> ranges = table->selectedRanges();
 	if (ranges.count() == 0)
-		return;
+		return nullptr;
 	int row = ranges.first().topRow();
 	QTableWidgetItem* item = table->item(row, 0);
-	if (!item)
-		return;
-	showEntry(item);
+	return showEntry(item);
 }
 
-void SearchResults::focusChanged(QWidget * old, QWidget * now)
-{
-	bool previouslyFocused, nowFocused;
-	TeXDocument * texDoc = qobject_cast<TeXDocument*>(parent());
-
-	if (!texDoc)
-		return;
-
-	if (old == NULL)
-		previouslyFocused = false;
-	else
-		previouslyFocused = isAncestorOf(old);
-
-	if (now == NULL)
-		nowFocused = false;
-	else
-		nowFocused = isAncestorOf(now);
-
-	if (!previouslyFocused && nowFocused)
-		texDoc->editor()->setPalette(editorModifiedPalette);
-	if (previouslyFocused && !nowFocused)
-		texDoc->editor()->setPalette(editorOriginalPalette);
-}
-
-PDFFindDialog::PDFFindDialog(PDFDocument *document)
+PDFFindDialog::PDFFindDialog(PDFDocumentWindow *document)
 	: QDialog(document)
 {
 	init(document);
 }
 
-void PDFFindDialog::init(PDFDocument *document)
+void PDFFindDialog::init(PDFDocumentWindow *document)
 {
 	setupUi(this);
 
 	buttonBox->button(QDialogButtonBox::Ok)->setText(tr("Find"));
 /*
-	connect(checkBox_allFiles, SIGNAL(toggled(bool)), this, SLOT(toggledAllFilesOption(bool)));
-	connect(checkBox_findAll, SIGNAL(toggled(bool)), this, SLOT(toggledFindAllOption(bool)));
-	connect(checkBox_regex, SIGNAL(toggled(bool)), this, SLOT(toggledRegexOption(bool)));
-	connect(checkBox_selection, SIGNAL(toggled(bool)), this, SLOT(toggledSelectionOption(bool)));
-	connect(searchText, SIGNAL(textChanged(const QString&)), this, SLOT(checkRegex(const QString&)));
+	connect(checkBox_allFiles, &QCheckBox::toggled, this, &PDFFindDialog::toggledAllFilesOption);
+	connect(checkBox_findAll, &QCheckBox::toggled, this, &PDFFindDialog::toggledFindAllOption);
+	connect(checkBox_regex, &QCheckBox::toggled, this, &PDFFindDialog::toggledRegexOption);
+	connect(checkBox_selection, &QCheckBox::toggled, this, &PDFFindDialog::toggledSelectionOption);
+	connect(searchText, &QLineEdit::textChanged, this, &PDFFindDialog::checkRegex);
 */
-	QSETTINGS_OBJECT(settings);
-	QString	str = settings.value("searchText").toString();
+	Tw::Settings settings;
+	QString	str = settings.value(QString::fromLatin1("searchText")).toString();
 	searchText->setText(str);
 	searchText->selectAll();
-	
+
 	// if findAll is enabled, revisit the saving of settings in
 	// PDFFindDialog::doFindDialog (and enable saving findAll if it's reasonable
 	// to override the setting (also for searches in the editor))
 	checkBox_findAll->setEnabled(false);
 	bool findAll = false;
 /*
-	bool findAll = settings.value("searchFindAll").toBool();
+	bool findAll = settings.value(QString::fromLatin1("searchFindAll")).toBool();
 	checkBox_findAll->setChecked(findAll);
 */
-	bool wrapOption = settings.value("searchWrap").toBool();
+	bool wrapOption = settings.value(QString::fromLatin1("searchWrap")).toBool();
 	checkBox_wrap->setEnabled(!findAll);
 	checkBox_wrap->setChecked(wrapOption);
 
-	QTextDocument::FindFlags flags = (QTextDocument::FindFlags)settings.value("searchFlags").toInt();
+	QTextDocument::FindFlags flags = static_cast<QTextDocument::FindFlags>(settings.value(QString::fromLatin1("searchFlags")).toInt());
 	checkBox_case->setChecked((flags & QTextDocument::FindCaseSensitively) != 0);
 //	checkBox_words->setChecked((flags & QTextDocument::FindWholeWords) != 0);
 //	checkBox_backwards->setChecked((flags & QTextDocument::FindBackward) != 0);
@@ -670,42 +636,42 @@ void PDFFindDialog::init(PDFDocument *document)
 	// Searching backwards currently doesn't work
 	// Might be a bug in Poppler
 	checkBox_backwards->setEnabled(false);
-	
-	checkBox_sync->setChecked(settings.value("searchPdfSync").toBool());
+
+	checkBox_sync->setChecked(settings.value(QString::fromLatin1("searchPdfSync")).toBool());
 	checkBox_sync->setEnabled(document->hasSyncData());
-	
+
 	QMenu *recentItemsMenu = new QMenu(this);
-	QStringList recentStrings = settings.value("recentSearchStrings").toStringList();
-	if (recentStrings.size() == 0)
+	QStringList recentStrings = settings.value(QString::fromLatin1("recentSearchStrings")).toStringList();
+	if (recentStrings.empty())
 		recentItemsMenu->addAction(tr("No recent search strings"))->setEnabled(false);
 	else {
 		foreach (const QString& str, recentStrings)
-			connect(recentItemsMenu->addAction(str), SIGNAL(triggered()), this, SLOT(setSearchText()));
+			connect(recentItemsMenu->addAction(str), &QAction::triggered, this, &PDFFindDialog::setSearchText);
 	}
 	recentSearches->setMenu(recentItemsMenu);
 	searchText->installEventFilter(new RecentStringsKeyFilter(this, recentStrings));
 }
 
-QDialog::DialogCode PDFFindDialog::doFindDialog(PDFDocument *document)
+QDialog::DialogCode PDFFindDialog::doFindDialog(PDFDocumentWindow *document)
 {
 	PDFFindDialog dlg(document);
 
 	dlg.show();
-	DialogCode	result = (DialogCode)dlg.exec();
+	DialogCode result = static_cast<DialogCode>(dlg.exec());
 
 	if (result == Accepted) {
-		QSETTINGS_OBJECT(settings);
+		Tw::Settings settings;
 		QString str = dlg.searchText->text();
-		settings.setValue("searchText", str);
-		
-		QStringList recentStrings = settings.value("recentSearchStrings").toStringList();
+		settings.setValue(QString::fromLatin1("searchText"), str);
+
+		QStringList recentStrings = settings.value(QString::fromLatin1("recentSearchStrings")).toStringList();
 		recentStrings.removeAll(str);
 		recentStrings.prepend(str);
 		while (recentStrings.count() > kMaxRecentStrings)
 			recentStrings.removeLast();
-		settings.setValue("recentSearchStrings", recentStrings);
+		settings.setValue(QString::fromLatin1("recentSearchStrings"), recentStrings);
 
-		QTextDocument::FindFlags oldFlags = (QTextDocument::FindFlags)settings.value("searchFlags").toInt();
+		QTextDocument::FindFlags oldFlags = static_cast<QTextDocument::FindFlags>(settings.value(QString::fromLatin1("searchFlags")).toInt());
 		int flags = 0;
 		if (dlg.checkBox_case->isChecked())
 			flags |= QTextDocument::FindCaseSensitively;
@@ -715,15 +681,15 @@ QDialog::DialogCode PDFFindDialog::doFindDialog(PDFDocument *document)
 //		if (dlg.checkBox_backwards->isChecked())
 //			flags |= QTextDocument::FindBackward;
 		flags |= (oldFlags & QTextDocument::FindBackward);
-		
-		settings.setValue("searchFlags", (int)flags);
 
-//		settings.setValue("searchRegex", dlg.checkBox_regex->isChecked());
-		settings.setValue("searchWrap", dlg.checkBox_wrap->isChecked());
-//		settings.setValue("searchSelection", dlg.checkBox_selection->isChecked());
-//		settings.setValue("searchFindAll", dlg.checkBox_findAll->isChecked());
-//		settings.setValue("searchAllFiles", dlg.checkBox_allFiles->isChecked());
-		settings.setValue("searchPdfSync", dlg.checkBox_sync->isChecked());
+		settings.setValue(QString::fromLatin1("searchFlags"), static_cast<int>(flags));
+
+//		settings.setValue(QString::fromLatin1("searchRegex"), dlg.checkBox_regex->isChecked());
+		settings.setValue(QString::fromLatin1("searchWrap"), dlg.checkBox_wrap->isChecked());
+//		settings.setValue(QString::fromLatin1("searchSelection"), dlg.checkBox_selection->isChecked());
+//		settings.setValue(QString::fromLatin1("searchFindAll"), dlg.checkBox_findAll->isChecked());
+//		settings.setValue(QString::fromLatin1("searchAllFiles"), dlg.checkBox_allFiles->isChecked());
+		settings.setValue(QString::fromLatin1("searchPdfSync"), dlg.checkBox_sync->isChecked());
 	}
 
 	return result;
@@ -732,7 +698,7 @@ QDialog::DialogCode PDFFindDialog::doFindDialog(PDFDocument *document)
 void PDFFindDialog::setSearchText()
 {
 	QAction *act = qobject_cast<QAction*>(sender());
-	if (act != NULL) {
+	if (act) {
 		searchText->setText(act->text());
 		searchText->selectAll();
 	}
