@@ -1,6 +1,6 @@
 /*
 	This is part of TeXworks, an environment for working with TeX documents
-	Copyright (C) 2007-2020  Jonathan Kew, Stefan Löffler, Charlie Sharpsteen
+	Copyright (C) 2007-2023  Jonathan Kew, Stefan Löffler, Charlie Sharpsteen
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -20,24 +20,23 @@
 */
 
 #include "PrefsDialog.h"
+
+#include "CompletingEdit.h"
 #include "DefaultPrefs.h"
+#include "PDFDocumentWindow.h"
 #include "Settings.h"
 #include "TWApp.h"
-#include "PDFDocumentWindow.h"
-#include "TeXHighlighter.h"
-#include "CompletingEdit.h"
 #include "TWUtils.h"
+#include "TeXHighlighter.h"
 #include "document/SpellChecker.h"
 
-#include <QFontDatabase>
-#include <QTextCodec>
-#include <QSet>
 #include <QFileDialog>
+#include <QFontDatabase>
 #include <QMainWindow>
-#include <QToolBar>
-#include <QDesktopWidget>
-//#include <QtAlgorithms>
 #include <QMessageBox>
+#include <QSet>
+#include <QTextCodec>
+#include <QToolBar>
 
 PrefsDialog::PrefsDialog(QWidget *parent)
 	: QDialog(parent)
@@ -50,25 +49,25 @@ PrefsDialog::PrefsDialog(QWidget *parent)
 void PrefsDialog::init()
 {
 	setupUi(this);
-	
-	connect(buttonBox, SIGNAL(clicked(QAbstractButton*)), this, SLOT(buttonClicked(QAbstractButton*)));
-	
-	connect(binPathList, SIGNAL(itemSelectionChanged()), this, SLOT(updatePathButtons()));
-	connect(pathUp, SIGNAL(clicked()), this, SLOT(movePathUp()));
-	connect(pathDown, SIGNAL(clicked()), this, SLOT(movePathDown()));
-	connect(pathAdd, SIGNAL(clicked()), this, SLOT(addPath()));
-	connect(pathRemove, SIGNAL(clicked()), this, SLOT(removePath()));
 
-	connect(toolList, SIGNAL(itemSelectionChanged()), this, SLOT(updateToolButtons()));
-	connect(toolList, SIGNAL(itemDoubleClicked(QListWidgetItem*)), this, SLOT(editTool(QListWidgetItem*)));
-	connect(toolUp, SIGNAL(clicked()), this, SLOT(moveToolUp()));
-	connect(toolDown, SIGNAL(clicked()), this, SLOT(moveToolDown()));
-	connect(toolAdd, SIGNAL(clicked()), this, SLOT(addTool()));
-	connect(toolRemove, SIGNAL(clicked()), this, SLOT(removeTool()));
-	connect(toolEdit, SIGNAL(clicked()), this, SLOT(editTool()));
-	
-	connect(tabWidget, SIGNAL(currentChanged(int)), this, SLOT(changedTabPanel(int)));
-	
+	connect(buttonBox, &QDialogButtonBox::clicked, this, &PrefsDialog::buttonClicked);
+
+	connect(binPathList, &QListWidget::itemSelectionChanged, this, &PrefsDialog::updatePathButtons);
+	connect(pathUp, &QToolButton::clicked, this, &PrefsDialog::movePathUp);
+	connect(pathDown, &QToolButton::clicked, this, &PrefsDialog::movePathDown);
+	connect(pathAdd, &QToolButton::clicked, this, &PrefsDialog::addPath);
+	connect(pathRemove, &QToolButton::clicked, this, &PrefsDialog::removePath);
+
+	connect(toolList, &QListWidget::itemSelectionChanged, this, &PrefsDialog::updateToolButtons);
+	connect(toolList, &QListWidget::itemDoubleClicked, this, &PrefsDialog::editTool);
+	connect(toolUp, &QToolButton::clicked, this, &PrefsDialog::moveToolUp);
+	connect(toolDown, &QToolButton::clicked, this, &PrefsDialog::moveToolDown);
+	connect(toolAdd, &QToolButton::clicked, this, &PrefsDialog::addTool);
+	connect(toolRemove, &QToolButton::clicked, this, &PrefsDialog::removeTool);
+	connect(toolEdit, &QToolButton::clicked, this, [=]() { this->editTool(); });
+
+	connect(tabWidget, &QTabWidget::currentChanged, this, &PrefsDialog::changedTabPanel);
+
 	pathsChanged = toolsChanged = false;
 }
 
@@ -254,7 +253,7 @@ void PrefsDialog::refreshDefaultTool()
 {
 	QString val;
 	int toolIndex = -1, defaultIndex = -1;
-	
+
 	if (defaultTool->count() > 0)
 		val = defaultTool->currentText();
 	defaultTool->clear();
@@ -265,7 +264,7 @@ void PrefsDialog::refreshDefaultTool()
 		if (e.name() == QString::fromUtf8(DEFAULT_ENGINE_NAME))
 			defaultIndex = defaultTool->count() - 1;
 	}
-	
+
 	if (toolIndex >= 0)
 		defaultTool->setCurrentIndex(toolIndex);
 	else if (defaultIndex >= 0)
@@ -328,10 +327,11 @@ void PrefsDialog::restoreDefaults()
 			language->setCurrentIndex(kDefault_SpellcheckLanguage);
 			encoding->setCurrentIndex(encoding->findText(QString::fromLatin1("UTF-8")));
 			highlightCurrentLine->setChecked(kDefault_HighlightCurrentLine);
+			cursorWidth->setValue(kDefault_CursorWidth);
 			autocompleteEnabled->setChecked(kDefault_AutocompleteEnabled);
 			autoFollowFocusEnabled->setChecked(kDefault_AutoFollowFocusEnabled);
 			break;
-	
+
 		case 2:
 			// Preview
 			switch (kDefault_PreviewScaleOption) {
@@ -347,6 +347,9 @@ void PrefsDialog::restoreDefaults()
 				case 4:
 					fixedScale->setChecked(true);
 					break;
+				case 5:
+					fitContentWidth->setChecked(true);
+					break;
 			}
 			scale->setValue(kDefault_PreviewScale);
 			switch (kDefault_PDFPageMode) {
@@ -362,7 +365,14 @@ void PrefsDialog::restoreDefaults()
 				break;
 			}
 
-			resolution->setDpi(QApplication::desktop()->physicalDpiX());
+			pdfPaperColor->setColor(kDefault_PaperColor);
+
+			pdfRulerUnits->setCurrentIndex(kDefault_PreviewRulerUnits);
+			pdfRulerShow->setChecked(kDefault_PreviewRulerShow);
+
+			resolution->setDpi(QApplication::screens().first()->physicalDotsPerInch());
+
+			pdfPageCacheSizeMiB->setValue(kDefault_PDFPageCacheSizeMiB);
 
 			switch (TWSynchronizer::kDefault_Resolution_ToTeX) {
 				case TWSynchronizer::CharacterResolution:
@@ -400,7 +410,7 @@ void PrefsDialog::restoreDefaults()
 			}
 			circularMag->setChecked(kDefault_CircularMagnifier);
 			break;
-		
+
 		case 3:
 			// Typesetting
 			TWApp::instance()->setDefaultEngineList();
@@ -444,7 +454,6 @@ void PrefsDialog::initPathAndToolLists()
 
 const int kSystemLocaleIndex = 0;
 const int kEnglishLocaleIndex = 1;
-const int kFirstTranslationIndex = 1;
 
 typedef QPair<QString, QString> DictPair;
 
@@ -456,18 +465,18 @@ static bool dictPairLessThan(const DictPair& d1, const DictPair& d2)
 QDialog::DialogCode PrefsDialog::doPrefsDialog(QWidget *parent)
 {
 	PrefsDialog dlg(nullptr);
-	
+
 	QStringList nameList;
 	foreach (QTextCodec *codec, *TWUtils::findCodecs())
 		nameList.append(QString::fromUtf8(codec->name().constData()));
 	dlg.encoding->addItems(nameList);
-	
+
 	QStringList syntaxOptions = TeXHighlighter::syntaxOptions();
 	dlg.syntaxColoring->addItems(syntaxOptions);
-	
+
 	QStringList indentModes = CompletingEdit::autoIndentModes();
 	dlg.autoIndent->addItems(indentModes);
-	
+
 	QStringList quotesModes = CompletingEdit::smartQuotesModes();
 	dlg.smartQuotes->addItems(quotesModes);
 
@@ -493,13 +502,13 @@ QDialog::DialogCode PrefsDialog::doPrefsDialog(QWidget *parent)
 
 		dictList << qMakePair(label, dict);
 	}
-	qSort(dictList.begin(), dictList.end(), dictPairLessThan);
+	std::sort(dictList.begin(), dictList.end(), dictPairLessThan);
 	foreach (const DictPair& dict, dictList)
 		dlg.language->addItem(dict.first, dict.second);
-		
+
 	Tw::Settings settings;
 	// initialize controls based on the current settings
-	
+
 	// General
 	int oldIconSize = settings.value(QString::fromLatin1("toolBarIconSize"), kDefault_ToolBarIcons).toInt();
 	switch (oldIconSize) {
@@ -528,32 +537,31 @@ QDialog::DialogCode PrefsDialog::doPrefsDialog(QWidget *parent)
 			break;
 	}
 	dlg.openPDFwithTeX->setChecked(settings.value(QString::fromLatin1("openPDFwithTeX"), kDefault_OpenPDFwithTeX).toBool());
-	
+
 	QString oldLocale = settings.value(QString::fromLatin1("locale")).toString();
 	// System and English are predefined at index 0 and 1 (see constants above)
 	dlg.localePopup->addItem(tr("System default [%1]").arg(QLocale::languageToString(QLocale(QLocale::system().name()).language())));
 	int oldLocaleIndex = oldLocale.isEmpty() ? kSystemLocaleIndex : kEnglishLocaleIndex;
-	QStringList *trList = TWUtils::getTranslationList();
-	QStringList::ConstIterator iter;
 	QList< DictPair > displayList;
-	for (iter = trList->constBegin(); iter != trList->constEnd(); ++iter) {
-		QLocale loc(*iter);
+	foreach(QString trans, TWApp::getTranslationList()) {
+		QLocale loc(trans);
 		QLocale::Language	language = loc.language();
 		QString locName;
 		if (language == QLocale::C)
-			locName = *iter;
+			locName = trans;
 		else {
-			locName = QLocale::languageToString(language);
-			if (iter->contains(QChar::fromLatin1('_'))) {
-				QLocale::Country country  = loc.country();
-				if (country != QLocale::AnyCountry)
-					//: Country suffix for TeXworks translations (ex. "Portuguese (Brazil)")
-					locName += tr(" (%1)").arg(QLocale::countryToString(country));
+			QLocale::Country country  = loc.country();
+			if (trans.contains(QChar::fromLatin1('_')) && country != QLocale::AnyCountry) {
+				//: Language (%1) and Country (%2) for TeXworks translations (ex. "Portuguese (Brazil)")
+				locName = tr("%1 (%2)").arg(QLocale::languageToString(language), QLocale::countryToString(country));
+			}
+			else {
+				locName = QLocale::languageToString(language);
 			}
 		}
-		displayList << qMakePair(locName, *iter);
+		displayList << qMakePair(locName, trans);
 	}
-	qSort(displayList.begin(), displayList.end(), dictPairLessThan);
+	std::sort(displayList.begin(), displayList.end(), dictPairLessThan);
 
 	Q_FOREACH(DictPair p, displayList) {
 		dlg.localePopup->addItem(p.first, p.second);
@@ -561,7 +569,7 @@ QDialog::DialogCode PrefsDialog::doPrefsDialog(QWidget *parent)
 			oldLocaleIndex = dlg.localePopup->count() - 1;
 	}
 	dlg.localePopup->setCurrentIndex(oldLocaleIndex);
-	
+
 	// Editor
 	dlg.syntaxColoring->setCurrentIndex(settings.contains(QString::fromLatin1("syntaxColoring"))
 	                        ? 1 + syntaxOptions.indexOf(settings.value(QString::fromLatin1("syntaxColoring")).toString())
@@ -586,6 +594,7 @@ QDialog::DialogCode PrefsDialog::doPrefsDialog(QWidget *parent)
 	dlg.fontSize->setValue(font.pointSize());
 	dlg.encoding->setCurrentIndex(nameList.indexOf(QString::fromUtf8(TWApp::instance()->getDefaultCodec()->name().constData())));
 	dlg.highlightCurrentLine->setChecked(settings.value(QString::fromLatin1("highlightCurrentLine"), kDefault_HighlightCurrentLine).toBool());
+	dlg.cursorWidth->setValue(settings.value(QStringLiteral("cursorWidth"), kDefault_CursorWidth).toInt());
 	dlg.autocompleteEnabled->setChecked(settings.value(QString::fromLatin1("autocompleteEnabled"), kDefault_AutocompleteEnabled).toBool());
 	dlg.autoFollowFocusEnabled->setChecked(settings.value(QStringLiteral("autoFollowFocusEnabled"), kDefault_AutoFollowFocusEnabled).toBool());
 
@@ -608,6 +617,9 @@ QDialog::DialogCode PrefsDialog::doPrefsDialog(QWidget *parent)
 		case 4:
 			dlg.fixedScale->setChecked(true);
 			break;
+		case 5:
+			dlg.fitContentWidth->setChecked(true);
+			break;
 	}
 	dlg.scale->setValue(settings.value(QString::fromLatin1("previewScale"), kDefault_PreviewScale).toInt());
 	switch (settings.value(QString::fromLatin1("pdfPageMode"), kDefault_PDFPageMode).toInt()) {
@@ -623,15 +635,23 @@ QDialog::DialogCode PrefsDialog::doPrefsDialog(QWidget *parent)
 			break;
 	}
 
-	double oldResolution = settings.value(QString::fromLatin1("previewResolution"), QApplication::desktop()->physicalDpiX()).toDouble();
+	dlg.pdfPaperColor->setColor(settings.value(QStringLiteral("pdfPaperColor"), QVariant::fromValue<QColor>(kDefault_PaperColor)).value<QColor>());
+
+	dlg.pdfRulerUnits->setCurrentIndex(settings.value(QStringLiteral("pdfRulerUnits"), kDefault_PreviewRulerUnits).toInt());
+	dlg.pdfRulerShow->setChecked(settings.value(QStringLiteral("pdfRulerShow"), kDefault_PreviewRulerShow).toBool());
+
+	double oldResolution = settings.value(QString::fromLatin1("previewResolution"), QApplication::screens().first()->physicalDotsPerInch()).toDouble();
 	dlg.resolution->setDpi(oldResolution);
 
+	const int oldPDFPageCacheSize = settings.value(QStringLiteral("pdfPageCacheSizeMiB"), kDefault_PDFPageCacheSizeMiB).toInt();
+	dlg.pdfPageCacheSizeMiB->setValue(oldPDFPageCacheSize);
+
 	int oldSyncToTeX = settings.value(QString::fromLatin1("syncResolutionToTeX"), TWSynchronizer::kDefault_Resolution_ToTeX).toInt();
 	dlg.cbSyncToTeX->setCurrentIndex(oldSyncToTeX);
 
 	int oldSyncToPDF = settings.value(QString::fromLatin1("syncResolutionToPDF"), TWSynchronizer::kDefault_Resolution_ToPDF).toInt();
 	dlg.cbSyncToPDF->setCurrentIndex(oldSyncToPDF);
-	
+
 	int oldMagSize = settings.value(QString::fromLatin1("magnifierSize"), kDefault_MagnifierSize).toInt();
 	switch (oldMagSize) {
 		case 1:
@@ -646,7 +666,7 @@ QDialog::DialogCode PrefsDialog::doPrefsDialog(QWidget *parent)
 	}
 	bool oldCircular = settings.value(QString::fromLatin1("circularMagnifier"), kDefault_CircularMagnifier).toBool();
 	dlg.circularMag->setChecked(oldCircular);
-	
+
 	// Typesetting
 	dlg.initPathAndToolLists();
 	QVariant hideConsoleSetting = settings.value(QString::fromLatin1("autoHideConsole"), kDefault_HideConsole);
@@ -660,11 +680,11 @@ QDialog::DialogCode PrefsDialog::doPrefsDialog(QWidget *parent)
 	dlg.allowScriptFileWriting->setChecked(settings.value(QString::fromLatin1("allowScriptFileWriting"), kDefault_AllowScriptFileWriting).toBool());
 	dlg.allowSystemCommands->setChecked(settings.value(QString::fromLatin1("allowSystemCommands"), kDefault_AllowSystemCommands).toBool());
 	dlg.enableScriptingPlugins->setChecked(settings.value(QString::fromLatin1("enableScriptingPlugins"), kDefault_EnableScriptingPlugins).toBool());
-	// there is always at least JSScriptInterface
+	// there is always at least one built-in ScriptInterface
 	if (TWApp::instance()->getScriptManager()->languages().size() <= 1)
 		dlg.enableScriptingPlugins->setEnabled(false);
 	dlg.scriptDebugger->setChecked(settings.value(QString::fromLatin1("scriptDebugger"), kDefault_ScriptDebugger).toBool());
-	
+
 	// Decide which tab to select initially
 	if (sCurrentTab == -1) {
 		if (parent && parent->inherits("TeXDocument"))
@@ -676,14 +696,14 @@ QDialog::DialogCode PrefsDialog::doPrefsDialog(QWidget *parent)
 	}
 	if (sCurrentTab != dlg.tabWidget->currentIndex())
 		dlg.tabWidget->setCurrentIndex(sCurrentTab);
-	
+
 	dlg.show();
 
 	DialogCode result = static_cast<DialogCode>(dlg.exec());
 
 	if (result == Accepted) {
 		sCurrentTab = dlg.tabWidget->currentIndex();
-	
+
 		// General
 		int iconSize = 2;
 		if (dlg.smallIcons->isChecked())
@@ -700,16 +720,16 @@ QDialog::DialogCode PrefsDialog::doPrefsDialog(QWidget *parent)
 					TWUtils::applyToolbarOptions(theWindow, iconSize, showText);
 			}
 		}
-		
+
 		int launchOption = 1;
 		if (dlg.templateDialog->isChecked())
 			launchOption = 2;
 		else if (dlg.openDialog->isChecked())
 			launchOption = 3;
 		settings.setValue(QString::fromLatin1("launchOption"), launchOption);
-		
+
 		settings.setValue(QString::fromLatin1("openPDFwithTeX"), dlg.openPDFwithTeX->isChecked());
-		
+
 		if (dlg.localePopup->currentIndex() != oldLocaleIndex) {
 			switch (dlg.localePopup->currentIndex()) {
 				case kSystemLocaleIndex: // system locale
@@ -728,7 +748,7 @@ QDialog::DialogCode PrefsDialog::doPrefsDialog(QWidget *parent)
 					break;
 			}
 		}
-		
+
 		// Editor
 		settings.setValue(QString::fromLatin1("syntaxColoring"), dlg.syntaxColoring->currentText());
 		settings.setValue(QString::fromLatin1("autoIndent"), dlg.autoIndent->currentText());
@@ -754,6 +774,8 @@ QDialog::DialogCode PrefsDialog::doPrefsDialog(QWidget *parent)
 		settings.setValue(QString::fromLatin1("highlightCurrentLine"), highlightLine);
 		CompletingEdit::setHighlightCurrentLine(highlightLine);
 
+		settings.setValue(QStringLiteral("cursorWidth"), dlg.cursorWidth->value());
+
 		bool autocompleteEnabled = dlg.autocompleteEnabled->isChecked();
 		settings.setValue(QString::fromLatin1("autocompleteEnabled"), autocompleteEnabled);
 		CompletingEdit::setAutocompleteEnabled(autocompleteEnabled);
@@ -765,9 +787,13 @@ QDialog::DialogCode PrefsDialog::doPrefsDialog(QWidget *parent)
 		foreach (QWidget* widget, TWApp::instance()->allWidgets()) {
 			QTextEdit* editor = qobject_cast<QTextEdit*>(widget);
 			if (editor)
-			    editor->setTabStopWidth(dlg.tabWidth->value());
+#if QT_VERSION < QT_VERSION_CHECK(5, 10, 0)
+				editor->setTabStopWidth(dlg.tabWidth->value());
+#else
+				editor->setTabStopDistance(dlg.tabWidth->value());
+#endif
 		}
-		
+
 		// Preview
 		int scaleOption = 1;
 		if (dlg.fitWidth->isChecked())
@@ -776,6 +802,8 @@ QDialog::DialogCode PrefsDialog::doPrefsDialog(QWidget *parent)
 			scaleOption = 3;
 		else if (dlg.fixedScale->isChecked())
 			scaleOption = 4;
+		else if (dlg.fitContentWidth->isChecked())
+			scaleOption = 5;
 		int scale = dlg.scale->value();
 		settings.setValue(QString::fromLatin1("scaleOption"), scaleOption);
 		settings.setValue(QString::fromLatin1("previewScale"), scale);
@@ -791,6 +819,11 @@ QDialog::DialogCode PrefsDialog::doPrefsDialog(QWidget *parent)
 				break;
 		}
 
+		settings.setValue(QStringLiteral("pdfPaperColor"), dlg.pdfPaperColor->color());
+
+		settings.setValue(QStringLiteral("pdfRulerUnits"), dlg.pdfRulerUnits->currentIndex());
+		settings.setValue(QStringLiteral("pdfRulerShow"), dlg.pdfRulerShow->isChecked());
+
 		double resolution = dlg.resolution->dpi();
 		if (resolution != oldResolution) {
 			settings.setValue(QString::fromLatin1("previewResolution"), resolution);
@@ -801,6 +834,10 @@ QDialog::DialogCode PrefsDialog::doPrefsDialog(QWidget *parent)
 			}
 		}
 
+		const int pdfPageCacheSize = dlg.pdfPageCacheSizeMiB->value();
+		settings.setValue(QStringLiteral("pdfPageCacheSizeMiB"), pdfPageCacheSize);
+		QtPDF::Backend::Document::pageCache().setMaxCost(pdfPageCacheSize * 1024 * 1024);
+
 		int syncToTeX = dlg.cbSyncToTeX->currentIndex();
 		if (syncToTeX != oldSyncToTeX)
 			settings.setValue(QString::fromLatin1("syncResolutionToTeX"), syncToTeX);
@@ -854,7 +891,7 @@ QDialog::DialogCode PrefsDialog::doPrefsDialog(QWidget *parent)
 int PrefsDialog::sCurrentTab = -1;
 
 ToolConfig::ToolConfig(QWidget *parent)
-	: QDialog(parent)	
+	: QDialog(parent)
 {
 	init();
 }
@@ -862,13 +899,13 @@ ToolConfig::ToolConfig(QWidget *parent)
 void ToolConfig::init()
 {
 	setupUi(this);
-	
-	connect(arguments, SIGNAL(itemSelectionChanged()), this, SLOT(updateArgButtons()));
-	connect(argUp, SIGNAL(clicked()), this, SLOT(moveArgUp()));
-	connect(argDown, SIGNAL(clicked()), this, SLOT(moveArgDown()));
-	connect(argAdd, SIGNAL(clicked()), this, SLOT(addArg()));
-	connect(argRemove, SIGNAL(clicked()), this, SLOT(removeArg()));
-	connect(btnBrowseForProgram, SIGNAL(clicked()), this, SLOT(browseForProgram()));
+
+	connect(arguments, &QListWidget::itemSelectionChanged, this, &ToolConfig::updateArgButtons);
+	connect(argUp, &QToolButton::clicked, this, &ToolConfig::moveArgUp);
+	connect(argDown, &QToolButton::clicked, this, &ToolConfig::moveArgDown);
+	connect(argAdd, &QToolButton::clicked, this, &ToolConfig::addArg);
+	connect(argRemove, &QToolButton::clicked, this, &ToolConfig::removeArg);
+	connect(btnBrowseForProgram, &QPushButton::clicked, this, &ToolConfig::browseForProgram);
 }
 
 void ToolConfig::browseForProgram()
@@ -940,7 +977,7 @@ void ToolConfig::removeArg()
 QDialog::DialogCode ToolConfig::doToolConfig(QWidget *parent, Engine &engine)
 {
 	ToolConfig dlg(parent);
-	
+
 	dlg.toolName->setText(engine.name());
 	dlg.program->setText(engine.program());
 	dlg.arguments->addItems(engine.arguments());
@@ -949,7 +986,7 @@ QDialog::DialogCode ToolConfig::doToolConfig(QWidget *parent, Engine &engine)
 		item->setFlags(item->flags() | Qt::ItemIsEditable);
 	}
 	dlg.viewPdf->setChecked(engine.showPdf());
-	
+
 	dlg.show();
 
 	DialogCode result = static_cast<DialogCode>(dlg.exec());
