@@ -1,6 +1,6 @@
 /*
 	This is part of TeXworks, an environment for working with TeX documents
-	Copyright (C) 2019  Stefan Löffler
+	Copyright (C) 2019-2022  Stefan Löffler
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -20,7 +20,7 @@
 */
 #include <QtTest/QtTest>
 
-#include "../plugins-src/TWLuaPlugin/LuaScriptInterface.h"
+#include "scripting/ScriptLanguageInterface.h"
 
 namespace UnitTest {
 
